#
# spec file for package ghc-tasty-quickcheck
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name tasty-quickcheck
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.11.1
Release:        2.2
Summary:        QuickCheck support for the Tasty test framework
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-optparse-applicative-devel
BuildRequires:  ghc-optparse-applicative-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-regex-tdfa-devel
BuildRequires:  ghc-regex-tdfa-prof
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
%endif

%description
QuickCheck support for the Tasty test framework.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Jun  3 2025 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.11.1 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Jan  6 2025 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.11.1 revision 1.
  Version 0.11.1
  - -------------
  * Add timeouts for individual tests within a property
    ([#425](https://github.com/UnkindPartition/tasty/pull/425)).
  * Define `showDefaultValue` for `QuickCheckTests`,
    `QuickCheckMaxSize` and `QuickCheckMaxRatio`
    ([#428](https://github.com/UnkindPartition/tasty/pull/428)).
  * Print the number of QuickCheck shrinks in the progress message
    ([#431](https://github.com/UnkindPartition/tasty/pull/431)).
  * Drop support for GHC 7.10.
* Sat Jun 22 2024 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.11.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/tasty-quickcheck-0.11/src/CHANGELOG.md
* Mon Apr 22 2024 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.10.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Sep 10 2023 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.10.3 revision 1.
  Version 0.10.3
  - -------------
  * Print Quickcheck progress using Tasty progress reporting.
    ([#311](https://github.com/UnkindPartition/tasty/pull/311)).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sat Nov 20 2021 Peter Simons <psimons@suse.com>
- Update tasty-quickcheck to version 0.10.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/tasty-quickcheck-0.10.2/src/CHANGELOG.md
* Fri Dec 18 2020 psimons@suse.com
- Update tasty-quickcheck to version 0.10.1.2.
  Version 0.10.1.2
  - ---------------
  The only point of this release is to introduce compatibility with GHCs back to 7.0
  (see https://github.com/feuerbach/tasty/pull/287).
  Note, however, that these changes are not merged to the master branch, and the
  future releases will only support the GHC/base versions from the last 5 years,
  as per our usual policy. To test with even older GHCs, you'll have to use this
  particular version of tasty-quickcheck (or have the constraint solver pick it
  for you when testing with older GHCs).
  The source of this release is in the `support-old-ghcs` branch of the tasty
  repository.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add tasty-quickcheck at version 0.10.1.1.
